@@ -4,7 +4,24 @@ import copy
 from datetime import datetime
 
 
-def deserialize_json(method, _json):
+class Printer:
+    def __init__(self, data):
+        self.data = data
+        self.print()
+
+    def print(self):
+
+        if isinstance(self.data, dict) or isinstance(self.data, list):
+            print(json.dumps(self.data, indent=3))
+        else:
+            try:
+                _json = deserialize_json(None, self.data)
+                print(json.dumps(_json, indent=3))
+            except:
+                print(self.data)
+
+
+def deserialize_json(method: str or None, _json):
     try:
         return json.loads(_json)
     except Exception as e:
@@ -45,6 +62,8 @@ def get_error(method, *args, **kwargs):
         for i in args:
             error_string += "\n{}".format(i)
 
+    if not method:
+        method = "Unknown"
     raise SystemExit("{} ERROR:\n{}".format(method.upper(), error_string))
 
 
@@ -340,6 +359,54 @@ def make_insert_string_v3(payload: dict, table: str):
 
     _values = "{}".format("".join("'{}', ".format(e) for e in list(_val)))[:-2].replace("'NULL'", "NULL")
 
+    _query = "INSERT INTO {table} ({keys}) VALUES ({values}) ON CONFLICT (campaign_id) DO NOTHING".format(
+        table=table,
+        keys=_keys,
+        values=_values)
+
+    return _query
+
+
+def make_insert_string_v4(payload: dict, table: str):
+    _keys = "{}".format("".join("{}, ".format(e) for e in list(payload.keys())))[:-2]
+    _values = ""
+
+    _val = []
+    for _v in payload.values():
+
+        if isinstance(_v, str):
+            _val.append(_v.replace("'", "''"))
+
+        elif isinstance(_v, int):
+            _val.append(_v)
+
+        elif isinstance(_v, dict):
+
+            if not _v:
+                _val.append("'{}'")
+
+            else:
+                _v = json.dumps(_v)
+                _v = _v.replace("'", "''")
+                _val.append(json.dumps(_v).replace('"{', "{").replace('}"', "}").replace("\\", ""))
+
+        elif isinstance(_v, list):
+            if not _v:
+                _val.append("{}")
+            else:
+                _val.append(str(_v).replace("'", '"').replace("[", "{").replace("]", "}"))
+
+        elif isinstance(_v, bool):
+            _val.append("{}".format(_v))
+
+        elif not _v:
+            _val.append("NULL")
+
+        else:
+            raise ValueError("Unsupported value type: '{}'".format(type(_v)))
+
+    _values = "{}".format("".join("'{}', ".format(e) for e in list(_val)))[:-2].replace("'NULL'", "NULL")
+
     _query = "INSERT INTO {table} ({keys}) VALUES ({values})".format(
         table=table,
         keys=_keys,
@@ -431,54 +498,6 @@ def make_update_string_v2(payload, table, key, key_value):
     return update_string
 
 
-def make_insert_string_v3(payload: dict, table: str):
-    _keys = "{}".format("".join("{}, ".format(e) for e in list(payload.keys())))[:-2]
-    _values = ""
-
-    _val = []
-    for _v in payload.values():
-
-        if isinstance(_v, str):
-            _val.append(_v.replace("'", "''"))
-
-        elif isinstance(_v, int):
-            _val.append(_v)
-
-        elif isinstance(_v, dict):
-
-            if not _v:
-                _val.append("'{}'")
-
-            else:
-                _v = json.dumps(_v)
-                _v = _v.replace("'", "''")
-                _val.append(json.dumps(_v).replace('"{', "{").replace('}"', "}").replace("\\", ""))
-
-        elif isinstance(_v, list):
-            if not _v:
-                _val.append("{}")
-            else:
-                _val.append(str(_v).replace("'", '"').replace("[", "{").replace("]", "}"))
-
-        elif isinstance(_v, bool):
-            _val.append("{}".format(_v))
-
-        elif not _v:
-            _val.append("NULL")
-
-        else:
-            raise ValueError("Unsupported value type: '{}'".format(type(_v)))
-
-    _values = "{}".format("".join("'{}', ".format(e) for e in list(_val)))[:-2].replace("'NULL'", "NULL")
-
-    _query = "INSERT INTO {table} ({keys}) VALUES ({values}) ON CONFLICT (campaign_id) DO NOTHING".format(
-        table=table,
-        keys=_keys,
-        values=_values)
-
-    return _query
-
-
 def make_update_string_v3(payload, table, key, key_value):
     string = ""
 
